const mimeTypeMap: Record<string, string[]> = {
  "504B0304": ["xls", "xlsx"],
};

export function fileTypeCheck(file: File, validFileTypes?: string[]) {
  if (!file?.type || !validFileTypes?.slice) {
    return Promise.reject();
  }

  const suffix = file.name.split(".").pop() || "";

  if (!validFileTypes?.includes(suffix)) {
    return Promise.reject();
  }

  return new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.onloadend = (evt) => {
      if (evt.target?.readyState === FileReader.DONE) {
        const uint = new Uint8Array(evt.target.result as ArrayBuffer);
        const bytes: string[] = [];
        uint.forEach((byte) => bytes.push(byte.toString(16).padStart(2, "0")));
        const hex = bytes.join("").toUpperCase();
        
        const mimeTypes = mimeTypeMap[hex];

        const find = validFileTypes.find((t) => mimeTypes.includes(t));

        if (find) {
          return resolve(find);
        }

        return reject(mimeTypes)
      }
    };
    const blob = file.slice(0, 4);
    reader.readAsArrayBuffer(blob);
  });
}
